==> org.eclipse.papyrus.gmf.codegen.xtend.source_1.0.0.202103181703.jar: xpt/editor/extensions.java <==
/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 * 	 Dmitry Stadnik (Borland) - initial API and implementation
 * 	 Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 */
package xpt.editor;

import com.google.common.base.Objects;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenApplication;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenEditorGenerator;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common;

@Singleton
@SuppressWarnings("all")
public class extensions {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  private MatchingStrategy xptMatching;
  
  @Inject
  private ActionBarContributor xptActionBarContributor;
  
  @Inject
  private Editor xptEditor;
  
  @Inject
  private CreationWizard xptCreationWizard;
  
  @Inject
  private InitDiagramFileAction xptInitDiagramFileAction;
  
  public CharSequence extensions(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _extraLineBreak = this._common.extraLineBreak();
    _builder.append(_extraLineBreak);
    _builder.newLineIfNotEmpty();
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace);
    _builder.append("<extension point=\"org.eclipse.ui.editors\" id=\"gmf-editor\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<editor");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_3);
    _builder.append("id=\"");
    String _iD = it.getEditor().getID();
    _builder.append(_iD);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_4);
    _builder.append("name=\"%editorName\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_5);
    _builder.append("icon=\"");
    String _iconPathX = it.getEditor().getIconPathX();
    _builder.append(_iconPathX);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_6);
    _builder.append("extensions=\"");
    String _diagramFileExtension = it.getDiagramFileExtension();
    _builder.append(_diagramFileExtension);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_7);
    _builder.append("default=\"true\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_8);
    _builder.append("class=\"");
    CharSequence _qualifiedClassName = this.xptEditor.qualifiedClassName(it.getEditor());
    _builder.append(_qualifiedClassName);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_9);
    _builder.append("matchingStrategy=\"");
    CharSequence _qualifiedClassName_1 = this.xptMatching.qualifiedClassName(it.getDiagram());
    _builder.append(_qualifiedClassName_1);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_10 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_10);
    _builder.append("contributorClass=\"");
    CharSequence _qualifiedClassName_2 = this.xptActionBarContributor.qualifiedClassName(it.getEditor());
    _builder.append(_qualifiedClassName_2);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_11 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_11);
    _builder.append("</editor>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_12 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_12);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    CharSequence _extraLineBreak_1 = this._common.extraLineBreak();
    _builder.append(_extraLineBreak_1);
    String _outTab = this.outTab();
    _builder.append(_outTab);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_13 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_13);
    _builder.append("<extension point=\"org.eclipse.ui.contexts\" id=\"ui-context\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_14 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_14);
    CharSequence _xmlGeneratedTag_1 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_1);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_15 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_15);
    _builder.append("<context");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_16 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_16);
    _builder.append("description=\"%context.description\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_17 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_17);
    _builder.append("id=\"");
    String _contextID = it.getEditor().getContextID();
    _builder.append(_contextID);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_18 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_18);
    _builder.append("name=\"%context.name\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_19 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_19);
    _builder.append("parentId=\"org.eclipse.gmf.runtime.diagram.ui.diagramContext\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_20 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_20);
    _builder.append("</context>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_21 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_21);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    String _tripleSpace_22 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_22);
    _builder.append("<extension point=\"org.eclipse.ui.newWizards\" id=\"creation-wizard\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_23 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_23);
    CharSequence _xmlGeneratedTag_2 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_2);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_24 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_24);
    _builder.append("<wizard");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_25 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_25);
    _builder.append("name=\"%newWizardName\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_26 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_26);
    _builder.append("icon=\"");
    String _creationWizardIconPathX = it.getDiagram().getCreationWizardIconPathX();
    _builder.append(_creationWizardIconPathX);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_27 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_27);
    _builder.append("category=\"");
    String _creationWizardCategoryID = it.getDiagram().getCreationWizardCategoryID();
    _builder.append(_creationWizardCategoryID);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_28 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_28);
    _builder.append("class=\"");
    CharSequence _qualifiedClassName_3 = this.xptCreationWizard.qualifiedClassName(it.getDiagram());
    _builder.append(_qualifiedClassName_3);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_29 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_29);
    _builder.append("id=\"");
    CharSequence _qualifiedClassName_4 = this.xptCreationWizard.qualifiedClassName(it.getDiagram());
    _builder.append(_qualifiedClassName_4);
    _builder.append("ID\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_30 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_30);
    _builder.append("<description>%newWizardDesc</description>  ");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_31 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_31);
    _builder.append("</wizard>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_32 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_32);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      boolean _generateInitDiagramAction = it.getDiagram().generateInitDiagramAction();
      if (_generateInitDiagramAction) {
        {
          GenApplication _application = it.getApplication();
          boolean _equals = Objects.equal(null, _application);
          if (_equals) {
            String _tripleSpace_33 = this._common.tripleSpace(1);
            _builder.append(_tripleSpace_33);
            _builder.append("<extension point=\"org.eclipse.ui.popupMenus\" id=\"init-diagram-action\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_34 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_34);
            CharSequence _xmlGeneratedTag_3 = this._common.xmlGeneratedTag();
            _builder.append(_xmlGeneratedTag_3);
            _builder.newLineIfNotEmpty();
            String _tripleSpace_35 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_35);
            _builder.append("<objectContribution");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_36 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_36);
            _builder.append("id=\"");
            String _iD_1 = it.getPlugin().getID();
            _builder.append(_iD_1);
            _builder.append(".InitDiagram\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_37 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_37);
            _builder.append("nameFilter=\"*.");
            String _domainFileExtension = it.getDomainFileExtension();
            _builder.append(_domainFileExtension);
            _builder.append("\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_38 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_38);
            _builder.append("objectClass=\"org.eclipse.core.resources.IFile\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_39 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_39);
            _builder.append("<action");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_40 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_40);
            _builder.append("label=\"%initDiagramActionLabel\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_41 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_41);
            _builder.append("class=\"");
            CharSequence _qualifiedClassName_5 = this.xptInitDiagramFileAction.qualifiedClassName(it.getDiagram());
            _builder.append(_qualifiedClassName_5);
            _builder.append("\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_42 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_42);
            _builder.append("menubarPath=\"additions\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_43 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_43);
            _builder.append("enablesFor=\"1\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_44 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_44);
            _builder.append("id=\"");
            String _iD_2 = it.getPlugin().getID();
            _builder.append(_iD_2);
            _builder.append(".InitDiagramAction\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_45 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_45);
            _builder.append("</action>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_46 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_46);
            _builder.append("</objectContribution>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_47 = this._common.tripleSpace(1);
            _builder.append(_tripleSpace_47);
            _builder.append("</extension>");
            _builder.newLineIfNotEmpty();
          } else {
            String _tripleSpace_48 = this._common.tripleSpace(1);
            _builder.append(_tripleSpace_48);
            _builder.append("<extension point=\"org.eclipse.ui.actionSets\" id=\"init-diagram-action\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_49 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_49);
            CharSequence _xmlGeneratedTag_4 = this._common.xmlGeneratedTag();
            _builder.append(_xmlGeneratedTag_4);
            _builder.newLineIfNotEmpty();
            String _tripleSpace_50 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_50);
            _builder.append("<actionSet");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_51 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_51);
            _builder.append("label=\"%initDiagramActionLabel\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_52 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_52);
            _builder.append("visible=\"true\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_53 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_53);
            _builder.append("id=\"");
            String _iD_3 = it.getPlugin().getID();
            _builder.append(_iD_3);
            _builder.append(".InitDiagram\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_54 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_54);
            _builder.append("<action");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_55 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_55);
            _builder.append("label=\"%initDiagramActionLabel\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_56 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_56);
            _builder.append("class=\"");
            CharSequence _qualifiedClassName_6 = this.xptInitDiagramFileAction.qualifiedClassName(it.getDiagram());
            _builder.append(_qualifiedClassName_6);
            _builder.append("\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_57 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_57);
            _builder.append("menubarPath=\"file/additions\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_58 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_58);
            _builder.append("id=\"");
            String _iD_4 = it.getPlugin().getID();
            _builder.append(_iD_4);
            _builder.append(".InitDiagramAction\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_59 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_59);
            _builder.append("</action>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_60 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_60);
            _builder.append("</actionSet>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_61 = this._common.tripleSpace(1);
            _builder.append(_tripleSpace_61);
            _builder.append("</extension>");
            _builder.newLineIfNotEmpty();
          }
        }
        CharSequence _extraLineBreak_2 = this._common.extraLineBreak();
        _builder.append(_extraLineBreak_2);
        _builder.append(" ");
        String _tripleSpace_62 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_62);
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public String outTab() {
    return "\t";
  }
}

==> org.eclipse.papyrus.gmf.codegen.xtend.source_1.0.0.202205251048.jar: xpt/editor/extensions.java <==
/**
 * Copyright (c) 2007, 2009, 2013, 2021 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 * Dmitry Stadnik (Borland) - initial API and implementation
 * Michael Golubev (Montages) - #386838 - migrate to Xtend2
 * Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : 1.4 Merge papyrus extension templates into codegen.xtend
 * Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up
 */
package xpt.editor;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenEditorGenerator;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common;

@Singleton
@SuppressWarnings("all")
public class extensions {
  @Inject
  @Extension
  private Common _common;
  
  public CharSequence extensions(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t");
    _builder.newLine();
    String _outTab = this.outTab();
    _builder.append(_outTab);
    _builder.newLineIfNotEmpty();
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace);
    _builder.append("<extension point=\"org.eclipse.ui.contexts\" id=\"ui-context\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<context");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_3);
    _builder.append("description=\"%context.description\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_4);
    _builder.append("id=\"");
    String _contextID = it.getEditor().getContextID();
    _builder.append(_contextID);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_5);
    _builder.append("name=\"%context.name\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_6);
    _builder.append("parentId=\"org.eclipse.gmf.runtime.diagram.ui.diagramContext\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_7);
    _builder.append("</context>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_8);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    return _builder;
  }
  
  public String outTab() {
    return "\t";
  }
}
